pub trait Crisp {
type Truth;
// Required method
fn crisp(&self) -> Self::Truth;
}Expand description
Define this trait over the target type of a classifier, to convert it into its truth type
i.e. for a binary classifier returning a f64 this returns a bool which is true if the
prediction is greater 0.5. For a classifier returning an [f64;n] it returns the index of
the largest discriminant, which should be equal to the class index.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".